package mainPackage;

import java.awt.*;
import java.awt.event.*;
import java.sql.SQLException;

import javax.swing.*;

import windowsPackage.Customer;
import windowsPackage.Search;
import windowsPackage.Travel;

public class MainFrame {
	
	private static MainFrame mainFrameInstance;
	private Container contentPane;
	private JFrame mainFrame;
	private JPanel topPanel;
	private JPanel mainContent;
	
	private JComboBox rejseDropdown;
	private JComboBox kundeDropdown;
	private JComboBox bookingDropdown;
	private JPanel topMenuPanel;
	
	public MainFrame() {
		mainFrameInstance = this;
		mainContent = new JPanel();
		mainContent.setLayout(new BoxLayout(mainContent, BoxLayout.Y_AXIS));
		makeWindow();
	}
	
	private void makeWindow() {
		mainFrame = new JFrame("AirLion Booking System");
		mainFrame.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		mainFrame.setResizable(false);
		contentPane = mainFrame.getContentPane();
		
		BorderLayout bl = new BorderLayout();
		bl.setVgap(0);
		
		contentPane.setLayout(bl);
		
		makeImage();
		makeContent();

		contentPane.add(mainContent, BorderLayout.CENTER);
		mainFrame.pack();
		mainFrame.setVisible(true);
	}
	
	private Component makeMenu() {
		topMenuPanel = new JPanel();
		topMenuPanel.setLayout(new BorderLayout());
		
		JPanel menuPanel = new JPanel();
		menuPanel.setLayout(new GridLayout(1, 0, -2, -2));
				
		bookingDropdown = new JComboBox();	
		bookingDropdown.addItem("Booking");
		bookingDropdown.addItem("Ny booking");
		bookingDropdown.addItem("Rediger booking");
		
		bookingDropdown.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Object selected = bookingDropdown.getSelectedItem();
				
				if(selected.equals("Booking")) {
					return;
				}
				mainContent.remove(1);
				
				if(selected.equals("Ny booking")) {
					mainContent.add(new Search(3, mainFrame).getTopPanel());
				}
				else if(selected.equals("Rediger booking")) {
					mainContent.add(new Search(1, mainFrame).getTopPanel());
				}
				selectItemCustomer("Kunde");
				selectItemTravel("Rejse");
				mainFrame.pack();
				
			}
		});
		
		kundeDropdown = new JComboBox();
		kundeDropdown.addItem("Kunde");
		kundeDropdown.addItem("Ny kunde");
		kundeDropdown.addItem("Rediger kunde");
		
		kundeDropdown.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Object selected = kundeDropdown.getSelectedItem();
				if(selected.equals("Kunde")) {
					return;
				}
				mainContent.remove(1);
				if(selected.equals("Ny kunde")) 
					mainContent.add(new Customer(mainFrameInstance));
				else if(selected.equals("Rediger kunde"))
					mainContent.add(new Search(2, mainFrame).getTopPanel());
				selectItemBooking("Booking");
				selectItemTravel("Rejse");
				
				mainFrame.pack();
			}
		});
		
		rejseDropdown = new JComboBox();
		rejseDropdown.addItem("Rejse");
		rejseDropdown.addItem("Ny rejse");
		rejseDropdown.addItem("Rediger rejse");
		rejseDropdown.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				Object selected = rejseDropdown.getSelectedItem();
				if(selected.equals("Rejse")) {
					return;
				}
				if(selected.equals("Ny rejse")) {
					try {
						mainContent.remove(1);
						mainContent.add(new Travel(mainFrameInstance));
					}
					catch(SQLException e1) {
						JOptionPane.showMessageDialog(null, "Du skal vre forbundet til internettet!");
						MainFrame.removeContent();
						return;
					}

				}
				else if(selected.equals("Rediger rejse")) {
					mainContent.remove(1);
					mainContent.add(new Search(4, mainFrame).getTopPanel());
				}
				selectItemBooking("Booking");
				selectItemCustomer("Kunde");
				mainFrame.pack();	
			}
	});
		
		menuPanel.add(bookingDropdown);
		menuPanel.add(kundeDropdown);
		menuPanel.add(rejseDropdown);
		topMenuPanel.add(menuPanel, BorderLayout.NORTH);
		
		return topMenuPanel;
	}
	
	private void makeImage() {
		ImageIcon image = createImageIcon("AirLionNoCopyright.png", "En flyver!");
		JLabel img = new JLabel(image, JLabel.CENTER);
		/**
		 * Tilfjer en mouselistener til billedeikonet, som bringer brugeren tilbage til startsiden
		 * ved at klikke p billedet.
		 */
		img.addMouseListener(new selectMouseListener());
		contentPane.add(img, BorderLayout.NORTH);
	}
	
	private void makeContent() {
		topPanel = new JPanel();
		JPanel menuPanel = new JPanel();
		
		FlowLayout fl = new FlowLayout(FlowLayout.CENTER);
		fl.setVgap(20);
		
		
		topPanel.setLayout(fl);
		
		menuPanel.setLayout(new GridLayout(3,1,0,10));
		
		JPanel bookingPanel = new JPanel();
		bookingPanel.setBorder(BorderFactory.createTitledBorder(" Booking "));
		
		JPanel customerPanel = new JPanel();
		customerPanel.setBorder(BorderFactory.createTitledBorder(" Kunde "));
		
		JPanel travelPanel = new JPanel();
		travelPanel.setBorder(BorderFactory.createTitledBorder(" Rejse "));
		
		JButton newBooking = new JButton(" Ny booking ");
		newBooking.addActionListener(new BookingActionListener());
		JButton editBooking = new JButton(" Rediger booking ");
		editBooking.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				mainContent.remove(topPanel);
				mainContent.add(makeMenu());
				mainContent.add(new Search(1, mainFrame).getTopPanel());
				selectItemBooking("Rediger booking");
				mainFrame.pack();
			}
		});
		JButton newCustomer = new JButton(" Ny kunde ");
		newCustomer.addActionListener(new CustomerActionListener());
		JButton editCustomer = new JButton(" Rediger kunde ");
		editCustomer.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				mainContent.remove(topPanel);
				mainContent.add(makeMenu());
				mainContent.add(new Search(2, mainFrame).getTopPanel());
				selectItemCustomer("Rediger kunde");
				mainFrame.pack();
			}
		});
		JButton newTravel = new JButton(" Ny rejse ");
		newTravel.addActionListener(new TravelActionListener());
		JButton editTravel = new JButton(" Rediger rejse ");
		editTravel.addActionListener(new EditTravelActionListener());
			
		bookingPanel.add(newBooking);
		bookingPanel.add(editBooking);		
		customerPanel.add(newCustomer);
		customerPanel.add(editCustomer);
		travelPanel.add(newTravel);
		travelPanel.add(editTravel);
		
		menuPanel.add(bookingPanel);
		menuPanel.add(customerPanel);
		menuPanel.add(travelPanel);
		
		bookingPanel.setBackground(Color.WHITE);
		customerPanel.setBackground(Color.WHITE);
		travelPanel.setBackground(Color.WHITE);
		topPanel.setBackground(Color.WHITE);
		menuPanel.setBackground(Color.WHITE);
		contentPane.setBackground(Color.WHITE);
		
		topPanel.add(menuPanel);
		mainContent.add(topPanel);
	}
	
	/**
	 * Returner et ImageIcon eller null, hvis stien er forkert. 
	 * Kilde: http://docs.oracle.com/javase/tutorial/uiswing/components/icon.html
	 */
	protected ImageIcon createImageIcon(String path, String description) {
	    java.net.URL imgURL = getClass().getResource(path);
	    if (imgURL != null) {
	        return new ImageIcon(imgURL, description);
	    } else {
	        System.err.println("Couldn't find file: " + path);
	        return null;
	    }
	}

	
	public static void removeContent() {
		mainFrameInstance.resetScreen();
	}
	
	public void resetScreen() {
		mainContent.removeAll();
		makeContent();
		mainFrame.pack();
	}
	
	private void selectItemBooking(String selectedItem) {
		bookingDropdown.setSelectedItem(selectedItem);
	}
	private void selectItemCustomer(String selectedItem) {
		kundeDropdown.setSelectedItem(selectedItem);
	}
	private void selectItemTravel(String selectedItem) {
		rejseDropdown.setSelectedItem(selectedItem);
	}
	
	private class BookingActionListener implements ActionListener {
		public void actionPerformed(ActionEvent event) {
			mainContent.remove(topPanel);
			mainContent.add(makeMenu());
			mainContent.add(new Search(3, mainFrame).getTopPanel());
			selectItemBooking("Ny booking");
			mainFrame.pack();
		}
	}
	
	private class CustomerActionListener implements ActionListener {
		public void actionPerformed(ActionEvent event) {
			mainContent.remove(topPanel);
			mainContent.add(makeMenu());
			mainContent.add(new Customer(mainFrameInstance));
			selectItemCustomer("Ny kunde");
			mainFrame.pack();
		}
	}
		
	private class TravelActionListener implements ActionListener {
		public void actionPerformed(ActionEvent event) {
			mainContent.remove(topPanel);
			mainContent.add(makeMenu());

			try {
			mainContent.add(new Travel(mainFrameInstance));
			}
			catch(SQLException e1) {
			
			}
			selectItemTravel("Ny rejse");
			mainFrame.pack();
		}
	}
	
	private class EditTravelActionListener implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			mainContent.remove(topPanel);
			mainContent.add(makeMenu());
			mainContent.add(new Search(4, mainFrame).getTopPanel());
			selectItemTravel("Rediger rejse");
			mainFrame.pack();
		}
	}
	
	private class selectMouseListener extends MouseAdapter {
		public void mouseClicked(MouseEvent e) {
			mainContent.removeAll();
			contentPane.remove(mainContent);
			makeContent();
			contentPane.add(mainContent);
			mainFrame.pack();
		}
    	
    }
	
}
